<template>
  <LoadingLayout :loading="isLoading">
    <div class="recharge-result-view" v-bind="$attrs">
      <div class="recharge-result-view-title">{{ title }}</div>
      <div class="recharge-result-view-subtitle">订单号：{{ orderNo }}</div>
      <div class="recharge-result-view-remark">
        {{ detail.refundCheckRemark }},如有疑问请联系客服 {{ CustomerServicePhone }}（周一到周五
        9:00-17:30）
      </div>
      <div class="recharge-result-view-btn-wrapper">
        <div class="recharge-result-view-btn" @click="emit('goBackHome')">回首页</div>
      </div>
    </div>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { LifeRechargeConstants, useLifeRechargeContext } from '@life-payment/core-vue';
import { CustomerServicePhone } from '../../constants';
import { useQuery } from '@tanstack/vue-query';
import { computed } from 'vue';
import LoadingLayout from '../../components//Layout/LoadingLayout.vue';

defineOptions({
  name: 'OrderRefundResultView',
});

type Props = {
  title?: string;
  orderNo?: string;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
};

const props = withDefaults(defineProps<Props>(), {
  title: '退款失败',
});

const emit = defineEmits<{
  (e: 'goBackHome'): void;
}>();

const { blLifeRecharge } = useLifeRechargeContext();

const { data: detail, isLoading } = useQuery({
  queryKey: ['blLifeRecharge/getUserLifePayOrderDetail', props.orderNo],
  queryFn: async () => {
    return await blLifeRecharge.services.getUserLifePayOrderDetail(
      { orderNo: props.orderNo },
      {
        showLoading: false,
      }
    );
  },

  enabled: computed(() => !!props.orderNo),
});
</script>
